==> eslint-plugin-module-import-plugin-0.0.5.tgz: package/tests/lib/rules/path-checker.js <==
/**
 * @fileoverview feature sliced relative path checker
 * @author impuDEV
 */
"use strict";

//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

const rule = require("../../../lib/rules/path-checker"),
  RuleTester = require("eslint").RuleTester;


//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------

const ruleTester = new RuleTester({
  parserOptions: {ecmaVersion: 6, sourceType: 'module'}
});
ruleTester.run("path-checker", rule, {
  valid: [
    {
      filename: 'C:\\Users\\tim\\Desktop\\javascript\\production_project\\src\\entities\\Article',
      code: "import { addCommentFormActions, addCommentFormReduce } from '../../model/slices/addCommentFormSlice'",
      errors: [],
    }
],

  invalid: [
    {
      filename: 'C:\\Users\\tim\\Desktop\\javascript\\production_project\\src\\entities\\Article',
      code: "import { addCommentFormActions, addCommentFormReduce } from '@/entities/Article/model/slices/addCommentFormSlice'",
      errors: [{ message: "В рамках одного слайса все пути должны быть относительными"}],
      options: [
        {
          alias: '@'
        }
      ]
    },
    {
      filename: 'C:\\Users\\tim\\Desktop\\javascript\\production_project\\src\\entities\\Article',
      code: "import { addCommentFormActions, addCommentFormReduce } from 'entities/Article/model/slices/addCommentFormSlice'",
      errors: [{ message: "В рамках одного слайса все пути должны быть относительными"}],
    }
  ],
});

==> eslint-plugin-module-import-plugin-0.0.10.tgz: package/tests/lib/rules/path-checker.js <==
/**
 * @fileoverview feature sliced relative path checker
 * @author impuDEV
 */
"use strict";

//------------------------------------------------------------------------------
// Requirements
//------------------------------------------------------------------------------

const rule = require("../../../lib/rules/path-checker"),
  RuleTester = require("eslint").RuleTester;


//------------------------------------------------------------------------------
// Tests
//------------------------------------------------------------------------------

const ruleTester = new RuleTester({
  parserOptions: {ecmaVersion: 6, sourceType: 'module'}
});
ruleTester.run("path-checker", rule, {
  valid: [
    {
      filename: 'C:\\1Content\\DEV\\projs\\ulbi\\ulbi-advanced-production\\src\\entities\\Article',
      code: "import { addCommentFormActions, addCommentFormReduce } from '../../model/slices/addCommentFormSlice'",
      errors: [],
    }
],

  invalid: [
    {
      filename: 'C:\\1Content\\DEV\\projs\\ulbi\\ulbi-advanced-production\\src\\entities\\Article',
      code: "import { addCommentFormActions, addCommentFormReduce } from '@/entities/Article/model/slices/addCommentFormSlice'",
      errors: [{ message: "В рамках одного слайса все пути должны быть относительными"}],
      options: [
        {
          alias: '@'
        }
      ]
    },
    {
      filename: 'C:\\1Content\\DEV\\projs\\ulbi\\ulbi-advanced-production\\src\\entities\\Article',
      code: "import { addCommentFormActions, addCommentFormReduce } from 'entities/Article/model/slices/addCommentFormSlice'",
      errors: [{ message: "В рамках одного слайса все пути должны быть относительными"}],
    }
  ],
});
